@@ -275,16 +275,19 @@ class BaseOAuth2(OAuthAuth):
         if not self.STATE_PARAMETER and not self.REDIRECT_STATE:
             return None
         state = self.strategy.session_get(self.name + '_state')
-        if state:
-            request_state = self.data.get('state') or \
-                            self.data.get('redirect_state')
-            if not request_state:
-                raise AuthMissingParameter(self, 'state')
-            elif not state:
-                raise AuthStateMissing(self, 'state')
-            elif not request_state == state:
-                raise AuthStateForbidden(self)
-        return state
+        request_state = self.data.get('state') or \
+                        self.data.get('redirect_state')
+        if request_state and isinstance(request_state, list):
+            request_state = request_state[0]
+
+        if not request_state:
+            raise AuthMissingParameter(self, 'state')
+        elif not state:
+            raise AuthStateMissing(self, 'state')
+        elif not request_state == state:
+            raise AuthStateForbidden(self)
+        else:
+            return state
 
     def auth_complete_params(self, state=None):
         client_id, client_secret = self.get_key_and_secret()
@@ -355,9 +358,13 @@ class BaseOAuth2(OAuthAuth):
 
     def refresh_token(self, token, *args, **kwargs):
         params = self.refresh_token_params(token, *args, **kwargs)
-        request = self.request(self.REFRESH_TOKEN_URL or self.ACCESS_TOKEN_URL,
-                               params=params, headers=self.auth_headers(),
-                               method=self.REFRESH_TOKEN_METHOD)
+        url = self.REFRESH_TOKEN_URL or self.ACCESS_TOKEN_URL
+        method = self.REFRESH_TOKEN_METHOD
+        key = 'params' if method == 'GET' else 'data'
+        request_args = {'headers': self.auth_headers(),
+                        'method': method,
+                        key: params}
+        request = self.request(url, **request_args)
         return self.process_refresh_token_response(request, *args, **kwargs)
 
     def revoke_token_url(self, token, uid):
